# Current Topics

## Replace dspy with custom written prompt generator

### Why?

- Better control in prompt generation progress
- easier metrics tracking
- Implementing diverse prompt optimization strategies like Microsoft Sammo and co.

### Current State

- In planning

[Implementation Plan](replace-dspy/implementation_plan.md) for more on type safety


## WebUI Frontend

### Why?

- Intuitive management of flock and agents


### Current State

- In planning